@@ -14,11 +14,6 @@
 
 """Reddit object."""
 
-from . import backport
-backport.add_moves()
-from six.moves import (HTTPCookieProcessor, HTTPError, build_opener,
-                       http_cookiejar, http_client, urljoin)
-
 import json
 import os
 import platform
@@ -26,13 +21,13 @@ import six
 import sys
 from warnings import warn, warn_explicit
 
-from . import decorators
-from . import errors
-from . import helpers
-from . import objects
-from .settings import CONFIG
+from praw import decorators, errors, helpers, objects
+from praw.compat import (HTTPCookieProcessor,  # pylint: disable-msg=E0611
+                         HTTPError, build_opener, http_cookiejar, http_client,
+                         urljoin)
+from praw.settings import CONFIG
 
-__version__ = '1.0.7'
+__version__ = '1.0.8'
 UA_STRING = '%%s PRAW/%s Python/%s %s' % (__version__,
                                           sys.version.split()[0],
                                           platform.platform(True))
@@ -132,7 +127,7 @@ class Config(object):  # pylint: disable-msg=R0903
             self._short_domain = None
         self.timeout = float(obj['timeout'])
         try:
-            self.user = obj['user']
+            self.user = obj['user'] if obj['user'] else None
             self.pswd = obj['pswd']
         except KeyError:
             self.user = self.pswd = None
@@ -149,8 +144,8 @@ class Config(object):  # pylint: disable-msg=R0903
         """
         Return the short domain of the reddit.
 
-        Used to generate the shortlink. For reddit the short_domain is redd.it
-        and generate shortlinks like http://redd.it/y3r8u
+        Used to generate the shortlink. For reddit.com the short_domain is
+        redd.it and generate shortlinks like http://redd.it/y3r8u
         """
         if self._short_domain:
             return self._short_domain
@@ -404,8 +399,6 @@ class SubredditExtension(BaseReddit):
         return self.request_json(self.config['contributors'] %
                                  six.text_type(subreddit))
 
-    @decorators.require_login
-    @decorators.require_moderator
     def get_flair(self, subreddit, redditor):
         """Gets the flair for a user on the given subreddit."""
         url_data = {'name': six.text_type(redditor)}
@@ -413,7 +406,6 @@ class SubredditExtension(BaseReddit):
                                  six.text_type(subreddit), url_data=url_data)
         return data['users'][0]
 
-    @decorators.require_login
     def get_moderators(self, subreddit):
         """Get the list of moderators for the given subreddit."""
         return self.request_json(self.config['moderators'] %
@@ -510,29 +502,33 @@ class SubredditExtension(BaseReddit):
                      content_options='any', over_18=False, default_set=True,
                      show_media=False, domain='', domain_css=False,
                      domain_sidebar=False, header_hover_text='',
-                     prev_description_id=False,
-                     prev_public_description_id=False, **kwargs):
+                     prev_description_id=None,
+                     prev_public_description_id=None, wikimode='disabled',
+                     wiki_edit_age=30, wiki_edit_karma=100, **kwargs):
         """Set the settings for the given subreddit."""
-        def bool_str(item):
-            return 'on' if item else 'off'
-
         params = {'r': six.text_type(subreddit),
                   'sr': subreddit.content_id,
                   'title': title,
                   'public_description': public_description,
                   'description': description,
-                  'prev_description_id': prev_description_id or '',
-                  'prev_public_description_id': prev_public_description_id or '',
                   'lang': language,
                   'type': subreddit_type,
                   'link_type': content_options,
-                  'over_18': bool_str(over_18),
-                  'allow_top': bool_str(default_set),
-                  'show_media': bool_str(show_media),
+                  'over_18': 'on' if over_18 else 'off',
+                  'allow_top': 'on' if default_set else 'off',
+                  'show_media': 'on' if show_media else 'off',
                   'domain': domain or '',
-                  'domain_css': bool_str(domain_css),
-                  'domain_sidebar': bool_str(domain_sidebar),
-                  'header-title': header_hover_text or ''}
+                  'domain_css': 'on' if domain_css else 'off',
+                  'domain_sidebar': 'on' if domain_sidebar else 'off',
+                  'header-title': header_hover_text or '',
+                  'wikimode': wikimode,
+                  'wiki_edit_age': six.text_type(wiki_edit_age),
+                  'wiki_edit_karma': six.text_type(wiki_edit_karma)}
+        #if prev_description_id is not None:
+        params['prev_description_id'] = prev_description_id or ''
+        #if prev_public_description_id is not None:
+        params['prev_public_description_id'] = (prev_public_description_id
+                                                    or '')
         if kwargs:
             msg = 'Extra settings fields: {0}'.format(kwargs.keys())
             warn_explicit(msg, UserWarning, '', 0)
@@ -546,9 +542,15 @@ class SubredditExtension(BaseReddit):
     @decorators.require_moderator
     def set_stylesheet(self, subreddit, stylesheet):
         """Set stylesheet for the given subreddit."""
+        prev_stylesheet = self.get_stylesheet(subreddit)
+        warn('set_stylesheet is temporarily inefficient')
         params = {'r': six.text_type(subreddit),
+                  'prevstyle': prev_stylesheet['prevstyle'],
                   'stylesheet_contents': stylesheet,
                   'op': 'save'}  # Options: save / preview
+        # pylint: disable-msg=E1101,W0212
+        helpers._request.evict([self.config['stylesheet'] %
+                                six.text_type(subreddit)])
         return self.request_json(self.config['subreddit_css'], params)
 
     @decorators.require_login
@@ -689,11 +691,12 @@ class LoggedInExtension(BaseReddit):
         """
         Login to a reddit site.
 
-        If no user or password is provided, the settings file will be checked,
-        and finally the user will be prompted with raw_input and
-        getpass.getpass. If username was explicitly provided and password was
-        not, then we must ask for the password unless the username matches
-        what's provided in the config file.
+        Look for username first in parameter, then praw.ini and finally if both
+        were empty get it from stdin. Look for password in parameter, then
+        praw.ini (but only if username matches that in praw.ini) and finally
+        if they both are empty get it with getpass. Add the variables user
+        (username) and pswd (password) to your praw.ini file to allow for auto-
+        login.
         """
         if password and not username:
             raise Exception('Username must be provided when password is.')
@@ -702,13 +705,12 @@ class LoggedInExtension(BaseReddit):
             sys.stdout.write('Username: ')
             sys.stdout.flush()
             user = sys.stdin.readline().strip()
-        if username and username == self.config.user:
-            pswd = password or self.config.pswd
-        elif not username and self.config.user:
-            pswd = self.config.pswd
+            pswd = None
         else:
+            pswd = password or self.config.pswd
+        if not pswd:
             import getpass
-            pswd = password or getpass.getpass('Password for %s: ' % user)
+            pswd = getpass.getpass('Password for %s: ' % user)
 
         params = {'passwd': pswd,
                   'user': user}
