@@ -19,18 +19,17 @@
 """Tests. Split into classes according to what they test."""
 
 from __future__ import unicode_literals
-from . import backport
-backport.add_moves()
 
 import random
 import unittest
 import uuid
 import warnings
 from six import advance_iterator as six_next, text_type
-from six.moves import HTTPError, URLError, urljoin
 
-from . import Reddit, errors, helpers
-from .objects import Comment, LoggedInRedditor, Message, MoreComments
+from praw import Reddit, errors, helpers
+from praw.compat import (HTTPError, URLError,  # pylint: disable-msg=E0611
+                         urljoin)
+from praw.objects import Comment, LoggedInRedditor, Message, MoreComments
 
 USER_AGENT = 'PRAW_test_suite'
 
@@ -174,7 +173,7 @@ class EncodingTest(unittest.TestCase, AuthenticatedHelper):
 
     def test_author_encoding(self):
         # pylint: disable-msg=E1101
-        a1 = six_next(self.r.get_front_page()).author
+        a1 = six_next(self.r.get_new()).author
         a2 = self.r.get_redditor(text_type(a1))
         self.assertEqual(a1, a2)
         s1 = six_next(a1.get_submitted())
@@ -356,19 +355,20 @@ class SettingsTest(unittest.TestCase, AuthenticatedHelper):
         stylesheet = ('div.titlebox span.number:after {\ncontent: " %s"\n' %
                       uuid.uuid4())
         self.subreddit.set_stylesheet(stylesheet)
-        self.assertEqual(self.subreddit.get_stylesheet()['stylesheet'],
-                         stylesheet)
+        self.assertEqual(stylesheet,
+                         self.subreddit.get_stylesheet()['stylesheet'])
 
     def test_update_settings_description(self):
         self.maxDiff = None
         settings = self.subreddit.get_settings()
         settings['description'] = 'Description %s' % uuid.uuid4()
-        self.subreddit.update_settings(
-            description=settings['description'])
+        self.subreddit.update_settings(description=settings['description'])
         new = self.subreddit.get_settings()
-        # ignore prev_id values since those change on update
+        # The id should change, but nothing else
         key = 'prev_description_id'
-        settings[key] = new[key] = None
+        self.assertNotEqual(settings[key], new[key])
+        del settings[key]
+        del new[key]
         self.assertEqual(new, settings)
 
     def test_update_settings_public_description(self):
@@ -378,9 +378,11 @@ class SettingsTest(unittest.TestCase, AuthenticatedHelper):
         self.subreddit.update_settings(
             public_description=settings['public_description'])
         new = self.subreddit.get_settings()
-        # ignore prev_id values since those change on update
+        # The id should change, but nothing else
         key = 'prev_public_description_id'
-        settings[key] = new[key] = None
+        self.assertNotEqual(settings[key], new[key])
+        del settings[key]
+        del new[key]
         self.assertEqual(new, settings)
 
 
@@ -680,12 +682,24 @@ class RedditorTest(unittest.TestCase, AuthenticatedHelper):
             self.other = {'id': 'pa', 'name': 'PyApiTestUser3'}
         self.other_user = self.r.get_redditor(self.other['name'])
 
+    def test_disliked(self):
+        # Pulls from get_liked. Problem here may come from get_liked
+        item = six_next(self.r.user.get_liked())
+        item.downvote()
+        self.assertTrue(item in self.r.user.get_disliked())
+
     def test_get_redditor(self):
         self.assertEqual(self.other['id'], self.other_user.id)
 
     def test_friend(self):
         self.other_user.friend()
 
+    def test_liked(self):
+        # Pulls from get_disliked. Problem here may come from get_disliked
+        item = six_next(self.r.user.get_disliked())
+        item.upvote()
+        self.assertTrue(item in self.r.user.get_liked())
+
     def test_unfriend(self):
         self.other_user.unfriend()
 
@@ -693,6 +707,36 @@ class RedditorTest(unittest.TestCase, AuthenticatedHelper):
         self.assertTrue(isinstance(self.r.user, LoggedInRedditor))
 
 
+class RefreshableTest(unittest.TestCase, AuthenticatedHelper):
+    def setUp(self):
+        self.configure()
+        self.real_timeout = self.r.config.cache_timeout
+        self.r.config.cache_timeout = 0
+
+    def tearDown(self):
+        self.r.config.cache_timeout = self.real_timeout
+
+    def test_refresh_subreddit(self):
+        subreddit = self.r.get_subreddit(self.sr)
+        new_description = 'Description %s' % uuid.uuid4()
+        subreddit.update_settings(public_description=new_description)
+        self.assertNotEqual(subreddit.public_description, new_description)
+        subreddit.refresh()
+        self.assertEqual(subreddit.public_description, new_description)
+
+    def test_refresh_submission(self):
+        subreddit = self.r.get_subreddit(self.sr)
+        submission = six_next(subreddit.get_top())
+        same_submission = self.r.get_submission(submission_id=submission.id)
+        if submission.likes:
+            submission.downvote()
+        else:
+            submission.upvote()
+        self.assertEqual(submission.likes, same_submission.likes)
+        submission.refresh()
+        self.assertNotEqual(submission.likes, same_submission.likes)
+
+
 class SubmissionTest(unittest.TestCase, AuthenticatedHelper):
     def setUp(self):
         self.configure()
@@ -766,7 +810,7 @@ class SubmissionTest(unittest.TestCase, AuthenticatedHelper):
             self.fail('Could not find submission in saved links.')
 
     def test_short_link(self):
-        submission = six_next(self.r.get_front_page())
+        submission = six_next(self.r.get_new())
         if self.r.config.is_reddit:
             self.assertTrue(submission.id in submission.short_link)
         else:
